===============================
g2gtools
===============================

.. image:: https://badge.fury.io/py/g2gtools.png
    :target: http://badge.fury.io/py/g2gtools

.. image:: https://travis-ci.org/jax-cgd/g2gtools.png?branch=master
        :target: https://travis-ci.org/jax-cgd/g2gtools

.. image:: https://pypip.in/d/g2gtools/badge.png
        :target: https://pypi.python.org/pypi/g2gtools


A set of tools that facilitates genome to genome conversion for studying multiparent populations

* Free software: GNU General Public License v3 (GPLv3)
* Documentation: https://g2gtools.readthedocs.org.

